# Oiia Interpreter

An interpreter for the Oiia language, a fun and esoteric programming language.

## Installation

You can install the package via pip:

```bash
pip install spinning-cat-lang==0.1.0
```

## Usage

```python
from oiia_interpreter import OiiaInterpreter

interpreter = OiiaInterpreter()
interpreter.interpret("oiia oiia oiia oiia 10")
```

## License

This project is licensed under the MIT License. See the LICENSE file for details.